Crate popsicle

Crate popsicle 

Structs

Image
A simple wrapper around a File that ensures that the file is a file, and obtains the file’s size ahead of time.
Mount

Enums

DiskError
ImageError

Functions

disks_from_args
get_disk_args
Stores all discovered USB disk paths into the supplied disks vector.
write_to_disk
Writes an image to the specified disk.